@@ -172,13 +172,17 @@ def speak(text):
         file = '/wav01.wav'
         base64_data = res_data_speech
         ori_image_data = base64.b64decode(base64_data)
-        fout = open("alsovoice.mp3", 'wb')
-        fout.write(ori_image_data)
-        fout.close()
-        pygame.mixer.init()
-        pygame.mixer.music.load('alsovoice.mp3')
-        pygame.mixer.music.play()
-        return res_dict['ret']
+        try:
+            with open('alsovoice.mp3', "wb") as f:
+                f.write(ori_image_data)
+            f.close()
+            pygame.mixer.init()
+            pygame.mixer.music.load('alsovoice.mp3')
+            pygame.mixer.music.play()
+            return res_dict['ret']
+        except:
+            return -1
     else:
         return res_dict['ret']
-print(speak('你好'))
+def help():
+    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt"))
